pub fn forced_walk(
from: &DistanceMap,
to: &DistanceMap,
through: &Polygon,
tolerance: f64,
) -> Result<ForcedWalk, FarthestError>Expand description
The shortest walk from an origin of from to a target of to that
enters through, bracketed to within tolerance.
from is a distance map whose targets are the walk’s origins, to one
whose targets are its destinations; both must cover the same region and
barriers.
Errors
FarthestError::MismatchedMaps when the maps cover different free
space; otherwise as crate::farthest_point, except that a part of the
polygon no walk reaches is not an error: it only contributes nothing.